==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Додатак %1 није усаглашен са системом.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Блутут подешавања</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Укључи</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Блутут подешавања</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 повезано</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Повезивање...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Блутут</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Искључен</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Блутут</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Додај распоред тастатуре</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Датум и сат</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-часовно време</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-часовно време</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Подешавање времена</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Укључи мрежу</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Искључи мрежу</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Подешавање мреже</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Заиста желите да испразните %1 ставки/е?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Ова радња је неповратна</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Непознат уређај</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Непознат систем</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Покрени</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Демонтирај све</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Покретач Програма</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Модеран режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Ефикасан режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Врх</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Дно</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Десно</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Остави приказано</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Остави скривено</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Паметно скривање</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Позиција</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стање</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Додаци</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Приказ Активности</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Откачи</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Искључи жичану везу</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Укључи жичану везу</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Искључи бежичану везу</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Укључи бежичану везу</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Искључи мрежу</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Укључи мрежу</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Подешавање мреже</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Уређај је онемогућен</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Бежична веза: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Жичана веза: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Нисте повезани</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Повезивање</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Повезани сте, али нема интернета</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Мрежни кабл је ископчан</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бежична мрежа</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Жичана мрежа</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Неуспешно повезивање</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Жичана мрежа</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Жичана мрежа %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Онборд</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подeшавања</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Напајање</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Управљање напајањем</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Ниво %1, %2 мин преостало</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Ниво %1, %2 ч %3 мин преостало</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Пуни се %1, %2 мин преостало</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Пуни се %1, %2 ч %3 мин преостало</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Напуњено</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Ниво %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Пуни се %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Ниво %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Ниво %1, напуњено</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Прикажи Радну Површину</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Откачи</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Напајање</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Обустави</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Хибернација</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Закључај</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Одјави се</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Промени корисника</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Управљање напајањем</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Уређај</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Укључи</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ућуткај</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Подешавање звука</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Јачина %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Смеће</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Смеће - %1 ставка/и</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Смеће - %1 ставки/е</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Покрени</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Испразни</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Системска касета</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Бежична мрежа</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Бежична мрежа %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.1.orig.tar.xz: dde-dock-5.5.38.1/translations/dde-dock_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Додатак %1 није усаглашен са системом.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Авионски режим</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Укључи</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Подешавање авионског режима</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Авионски режим</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Блутут подешавања</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Укључи</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Блутут подешавања</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 повезано</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Повезивање...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Блутут</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Искључен</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Блутут</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Додај распоред тастатуре</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Датум и сат</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-часовно време</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-часовно време</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Подешавање времена</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Заиста желите да испразните %1 ставки/е?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Ова радња је неповратна</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Непознат уређај</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Непознат систем</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Покрени</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Демонтирај све</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Покретач Програма</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Изађи из безбедног режима</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Док - Безбедни режим</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Док је у безбедном режиму, изађите за нормалан приказ</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Модеран режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Ефикасан режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Врх</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Дно</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Десно</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Остави приказано</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Остави скривено</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Паметно скривање</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Позиција</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стање</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Вишеструки прикази</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Врх</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Дно</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Десно</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Позиција</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Smart hide</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status</source>
        <translation>Стање</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Мала</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Велика</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>На екрану где је показивач</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Само на главном екрану</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Приказ Активности</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Откачи</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Онборд</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Подeшавања</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Напајање</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Управљање напајањем</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Ниво %1, %2 мин преостало</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Ниво %1, %2 ч %3 мин преостало</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Пуни се %1, %2 мин преостало</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Пуни се %1, %2 ч %3 мин преостало</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Ниво %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Пуни се %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Ниво %1 ....</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Ниво %1, напуњено</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Закачи</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Прикажи Радну Површину</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Откачи</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Напајање</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Обустави</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Хибернација</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Закључај</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Одјави се</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Промени корисника</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Управљање напајањем</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Уређај</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Укључи</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ућуткај</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Подешавање звука</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Јачина %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Смеће</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Смеће - %1 ставка/и</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Смеће - %1 ставки/е</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Покрени</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Испразни</translation>
    </message>
</context>
</TS>
